@@ -351,10 +351,10 @@ dmapd_dpap_record_set_from_blob (DMAPRecord *_record, GByteArray *blob)
         ptr += sizeof (record->priv->mtime);
 
 	file = g_file_new_for_uri (location);
-        if (NULL == location) {
-                g_warning ("Could not open %s\n", location);
-                goto _done;
-        }
+	if (NULL == file) {
+		g_warning ("Could not open %s\n", location);
+		goto _done;
+	}
 
         stream = g_file_read (file, NULL, &error);
         if (NULL == stream) {
