@@ -225,7 +225,7 @@ thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filena
 		VipsImage *thumb = NULL;
 
 		/* This will just read in the header and is quick. */
-		im = vips_image_new_from_file (filename);
+		im = vips_image_new_from_file (filename, NULL);
 		if (NULL == im) {
 			g_warning ("    Error reading header from %s.\n", filename);
 			goto _done;
@@ -426,7 +426,7 @@ photo_meta_reader_vips_read (PhotoMetaReader *reader, DPAPRecord *record, const
                 goto _done;
         }
 
-	im = vips_image_new_from_file (path);
+	im = vips_image_new_from_file (path, NULL);
 	if (NULL == im) {
 		g_warning ("Could not open %s", path);
 		goto _done;
